<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:iwmo="http://www.istandaarden.nl/iwmo/3_0/basisschema/schema"
	xmlns:wmo303="http://www.istandaarden.nl/iwmo/3_0/wmo303/schema"
	xmlns:wmo323="http://www.istandaarden.nl/iwmo/3_0/wmo323/schema"
	>

	<!-- iWmo 3.0 TR316 version 2.2.8 (2021-01-25) -->

	<xsl:import href="../common/basis.xsl"/>
	<xsl:template match="*" mode="TR316"/>
	<xsl:template match="*" mode="check">
		<xsl:apply-templates select="*" mode="TR316"/>
	</xsl:template>

	<xsl:template match="wmo303:ProductReferentie" mode="TR316">
		<xsl:variable name="vReferentieNummer" select="normalize-space(iwmo:ReferentieNummer/text())" />
		<xsl:variable name="vVorigReferentieNummer" select="normalize-space(iwmo:VorigReferentieNummer/text())" />
		<xsl:variable name="vReferentie" select="iwmo:ReferentieNummer" />
		<xsl:variable name="vVorigReferentie" select="iwmo:VorigReferentieNummer" />
		
		<xsl:for-each select="
				ancestor-or-self::wmo303:Prestatie/preceding-sibling::wmo303:Prestatie/wmo303:ProductReferentie/iwmo:ReferentieNummer[text() = $vVorigReferentieNummer] |
				ancestor-or-self::wmo303:Client/preceding-sibling::wmo303:Client/wmo303:Prestaties/wmo303:Prestatie/wmo303:ProductReferentie/iwmo:ReferentieNummer[text() = $vVorigReferentieNummer]
				">
			<xsl:call-template name="checkvalue">
				<xsl:with-param name="pValues">!#</xsl:with-param>
				<xsl:with-param name="pRule">TR316</xsl:with-param>
				<xsl:with-param name="pExtra" select="$vVorigReferentie" />
			</xsl:call-template>
		</xsl:for-each>
		
		<xsl:for-each select="
				ancestor-or-self::wmo303:Prestatie/preceding-sibling::wmo303:Prestatie/wmo303:ProductReferentie/iwmo:VorigReferentieNummer[text() = $vReferentieNummer] |
				ancestor-or-self::wmo303:Client/preceding-sibling::wmo303:Client/wmo303:Prestaties/wmo303:Prestatie/wmo303:ProductReferentie/iwmo:VorigReferentieNummer[text() = $vReferentieNummer]
				">
			<xsl:call-template name="checkvalue">
				<xsl:with-param name="pValues">!#</xsl:with-param>
				<xsl:with-param name="pRule">TR316</xsl:with-param>
				<xsl:with-param name="pExtra" select="$vReferentie" />
			</xsl:call-template>
		</xsl:for-each>

		<xsl:if test="$vReferentieNummer = $vVorigReferentieNummer">
			<xsl:call-template name="addError">
				<xsl:with-param name="pRule">TR316</xsl:with-param>
				<xsl:with-param name="pElements" select="iwmo:ReferentieNummer | iwmo:VorigReferentieNummer" />
			</xsl:call-template>
		</xsl:if>
	</xsl:template>

	<xsl:template match="wmo323:ProductReferentie" mode="TR316">
		<xsl:variable name="vReferentieNummer" select="normalize-space(iwmo:ReferentieNummer/text())" />
		<xsl:variable name="vVorigReferentieNummer" select="normalize-space(iwmo:VorigReferentieNummer/text())" />
		<xsl:variable name="vReferentie" select="iwmo:ReferentieNummer" />
		<xsl:variable name="vVorigReferentie" select="iwmo:VorigReferentieNummer" />
		
		<xsl:for-each select="
				ancestor-or-self::wmo323:Prestatie/preceding-sibling::wmo323:Prestatie/wmo323:ProductReferentie/iwmo:ReferentieNummer[text() = $vVorigReferentieNummer] |
				ancestor-or-self::wmo323:Client/preceding-sibling::wmo323:Client/wmo323:Prestaties/wmo323:Prestatie/wmo323:ProductReferentie/iwmo:ReferentieNummer[text() = $vVorigReferentieNummer]
				">
			<xsl:call-template name="checkvalue">
				<xsl:with-param name="pValues">!#</xsl:with-param>
				<xsl:with-param name="pRule">TR316</xsl:with-param>
				<xsl:with-param name="pExtra" select="$vVorigReferentie" />
			</xsl:call-template>
		</xsl:for-each>
		
		<xsl:for-each select="
				ancestor-or-self::wmo323:Prestatie/preceding-sibling::wmo323:Prestatie/wmo323:ProductReferentie/iwmo:VorigReferentieNummer[text() = $vReferentieNummer] |
				ancestor-or-self::wmo323:Client/preceding-sibling::wmo323:Client/wmo323:Prestaties/wmo323:Prestatie/wmo323:ProductReferentie/iwmo:VorigReferentieNummer[text() = $vReferentieNummer]
				">
			<xsl:call-template name="checkvalue">
				<xsl:with-param name="pValues">!#</xsl:with-param>
				<xsl:with-param name="pRule">TR316</xsl:with-param>
				<xsl:with-param name="pExtra" select="$vReferentie" />
			</xsl:call-template>
		</xsl:for-each>
		
		<xsl:if test="$vReferentieNummer = $vVorigReferentieNummer">
			<xsl:call-template name="addError">
				<xsl:with-param name="pRule">TR316</xsl:with-param>
				<xsl:with-param name="pElements" select="iwmo:ReferentieNummer | iwmo:VorigReferentieNummer" />
			</xsl:call-template>
		</xsl:if>
	</xsl:template>

</xsl:stylesheet>
