<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:iwmo="http://www.istandaarden.nl/iwmo/3_0/basisschema/schema"
	xmlns:wmo304="http://www.istandaarden.nl/iwmo/3_0/wmo304/schema"
	>

	<!-- iWmo 3.0 TR320 version 2.2.8 (2021-01-25) -->

	<xsl:import href="../common/basis.xsl"/>
	<xsl:template match="*" mode="TR320"/>
	<xsl:template match="*" mode="check">
		<xsl:apply-templates select="*" mode="TR320"/>
	</xsl:template>

	<xsl:template match="wmo304:RetourBedragen" mode="TR320">
		<!-- Bereken SaldoIngediendeBedragregel -->
		<xsl:variable name="IngediendTotaalDebet" select="sum(ancestor-or-self::wmo304:Bericht/wmo304:Clienten/wmo304:Client/wmo304:Prestaties/wmo304:Prestatie/wmo304:IngediendeBedragPrestatie/iwmo:DeclaratieFactuurBedrag[iwmo:DebetCredit = 'D']/iwmo:Bedrag)"/>
		<xsl:variable name="IngediendTotaalCredit" select="sum(ancestor-or-self::wmo304:Bericht/wmo304:Clienten/wmo304:Client/wmo304:Prestaties/wmo304:Prestatie/wmo304:IngediendeBedragPrestatie/iwmo:DeclaratieFactuurBedrag[iwmo:DebetCredit = 'C']/iwmo:Bedrag)"/>
		<xsl:variable name="SaldoIngediendeBedragregel" select="$IngediendTotaalDebet - $IngediendTotaalCredit"/>

		<!-- Bereken SaldoToegekendeBedragregel -->
		<xsl:variable name="ToegekendTotaalDebet" select="sum(ancestor-or-self::wmo304:Bericht/wmo304:Clienten/wmo304:Client/wmo304:Prestaties/wmo304:Prestatie/wmo304:ToegekendeBedragPrestatie/iwmo:ToegekendBedrag[iwmo:DebetCredit = 'D']/iwmo:Bedrag)"/>
		<xsl:variable name="ToegekendTotaalCredit" select="sum(ancestor-or-self::wmo304:Bericht/wmo304:Clienten/wmo304:Client/wmo304:Prestaties/wmo304:Prestatie/wmo304:ToegekendeBedragPrestatie/iwmo:ToegekendBedrag[iwmo:DebetCredit = 'C']/iwmo:Bedrag)"/>
		<xsl:variable name="SaldoToegekendeBedragregel" select="$ToegekendTotaalDebet - $ToegekendTotaalCredit"/>

		<!-- Bepaal verschil E: = SaldoIngediendeBedragregel minus SaldoToegekende bedragregel-->
		<xsl:variable name="VerschilBedragregel" select="$SaldoIngediendeBedragregel - $SaldoToegekendeBedragregel"/>

		<!-- Maak van ToegekendTotaalBedrag een negatief getal als ToegekendDebetCredit waarde C heeft -->
		<xsl:variable name="ToegekendTotaalBedragDC">
			<xsl:choose>
				<xsl:when test="./iwmo:ToegekendTotaalBedrag/iwmo:DebetCredit/text() = 'C' ">
					<xsl:value-of select='./iwmo:ToegekendTotaalBedrag/iwmo:TotaalBedrag/text() * -1'/>
				</xsl:when>
				<xsl:otherwise><xsl:value-of select='./iwmo:ToegekendTotaalBedrag/iwmo:TotaalBedrag/text()'/></xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

		<!-- Maak van IngediendTotaalBedrag een negatief getal als IngediendDebetCredit waarde C heeft -->
		<xsl:variable name="IngediendTotaalBedragDC">
			<xsl:choose>
				<xsl:when test="./iwmo:IngediendTotaalBedrag/iwmo:DebetCredit/text() = 'C' ">
					<xsl:value-of select='./iwmo:IngediendTotaalBedrag/iwmo:TotaalBedrag/text() * -1'/>
				</xsl:when>
				<xsl:otherwise><xsl:value-of select='./iwmo:IngediendTotaalBedrag/iwmo:TotaalBedrag/text()'/></xsl:otherwise>
			</xsl:choose>
		</xsl:variable>

		<!-- Bepaal verschil F:= IngediendTotaalBedrag minus ToegekendTotaalBedrag-->
		<xsl:variable name="VerschilHeaderTotalen" select="$IngediendTotaalBedragDC - $ToegekendTotaalBedragDC"/>

		<!-- Controleren of verschil E overeenkomt met verschil F bedragen -->
		<xsl:if test="count(ancestor-or-self::wmo304:Bericht/wmo304:Header/wmo304:RetourCodes/*[local-name() = 'RetourCode'][text() != '0200' and text() != '8001']) = 0 and normalize-space($VerschilBedragregel) != normalize-space($VerschilHeaderTotalen)">
			<xsl:call-template name="addError">
				<xsl:with-param name="pRule">TR320</xsl:with-param>
				<xsl:with-param name="pCode">0001</xsl:with-param>
				<xsl:with-param name="pElements" select="
					iwmo:IngediendTotaalBedrag/iwmo:TotaalBedrag | iwmo:IngediendTotaalBedrag/iwmo:DebetCredit |
					iwmo:ToegekendTotaalBedrag/iwmo:TotaalBedrag | iwmo:ToegekendTotaalBedrag/iwmo:DebetCredit"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>

</xsl:stylesheet>
